@@ -13,7 +13,7 @@ from pynamodb.exceptions import TableError
 from pynamodb.types import RANGE
 from pynamodb.constants import (
     ITEM, STRING_SHORT, ALL, KEYS_ONLY, INCLUDE, REQUEST_ITEMS, UNPROCESSED_KEYS,
-    RESPONSES, KEYS, ITEMS, LAST_EVALUATED_KEY, EXCLUSIVE_START_KEY
+    RESPONSES, KEYS, ITEMS, LAST_EVALUATED_KEY, EXCLUSIVE_START_KEY, ATTRIBUTES
 )
 from pynamodb.models import Model
 from pynamodb.indexes import (
@@ -101,6 +101,7 @@ class SimpleUserModel(Model):
     numbers = NumberSetAttribute()
     aliases = UnicodeSetAttribute()
     icons = BinarySetAttribute()
+    views = NumberAttribute(null=True)
 
 
 class ThrottledUserModel(Model):
@@ -194,6 +195,8 @@ class ModelTestCase(TestCase):
         with patch(PATCH_METHOD) as req:
             req.return_value = HttpOK, MODEL_TABLE_DATA
             UserModel.create_table(read_capacity_units=2, write_capacity_units=2)
+            # The default region is us-east-1
+            self.assertEqual(req.call_args[0][0].region_name, 'us-east-1')
 
         # A table with a specified region
         self.assertEqual(RegionSpecificModel.region, 'us-west-1')
@@ -318,6 +321,48 @@ class ModelTestCase(TestCase):
             args = req.call_args[1]
             self.assertEqual(args, params)
 
+    def test_update_item(self):
+        """
+        Model.update_item
+        """
+        with patch(PATCH_METHOD) as req:
+            req.return_value = HttpOK(), SIMPLE_MODEL_TABLE_DATA
+            item = SimpleUserModel('foo', email='bar')
+
+        with patch(PATCH_METHOD) as req:
+            req.return_value = HttpOK(), {}
+            item.save()
+
+        with patch(PATCH_METHOD) as req:
+            req.return_value = HttpOK({}), {
+                ATTRIBUTES: {
+                    "views": {
+                        "N": "10"
+                    }
+                }
+            }
+            item.update_item('views', 10, action='add')
+            args = req.call_args[1]
+            params = {
+                'table_name': 'SimpleModel',
+                'return_values': 'ALL_NEW',
+                'key': {
+                    'user_name': {
+                        'S': 'foo'
+                    }
+                },
+                'attribute_updates': {
+                    'views': {
+                        'Action': 'ADD',
+                        'Value': {
+                            'N': '10'
+                        }
+                    }
+                },
+                'return_consumed_capacity': 'TOTAL'
+            }
+            self.assertEqual(args, params)
+
     def test_save(self):
         """
         Model.save
